#
# spec file for package python-mrcz
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-mrcz
Version:        0.5.7
Release:        1.2
Summary:        MRCZ meta-compressed image file-format library
License:        BSD-3-Clause
URL:            https://github.com/em-MRCZ/python-mrcz
Source:         https://github.com/em-MRCZ/python-mrcz/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://github.com/em-MRCZ/python-mrcz/pull/15 Numpy 2.0 and deprecation fixes
Patch:          numpy2.patch
# PATCH-FIX-UPSTREAM https://github.com/em-MRCZ/python-mrcz/pull/16 Remove distutils / support python >=3.12
Patch:          new-pythons.patch
BuildRequires:  %{python_module blosc}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Recommends:     python-blosc
BuildArch:      noarch
%python_subpackages

%description
mrcz is a package designed to supplement the venerable MRC image file
format with a highly efficient compressed variant, using the blosc
meta-compressor library to shrink files on disk and greatly accelerate
file input/output for the era of "Big Data" in electron and optical
microscopy.

%prep
%autosetup -p1
dos2unix README.rst

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc AUTHORS.txt README.rst
%license LICENSE.txt
%dir %{python_sitelib}/mrcz/
%pycache_only %{python_sitelib}/mrcz-%{version}-py%{python_version}.egg-info/
%pycache_only %{python_sitelib}/mrcz/*.py
%pycache_only %{python_sitelib}/mrcz/__pycache__/

%changelog
* Wed Nov 27 2024 Markéta Machová <mmachova@suse.com>
- Update to 0.5.7
  * Renamed np.product to np.prod as the old name is deprecated in NumPy 2.0.
- Add patch new-pythons.patch to fix build with Python 3.13
- Python 2 can be finally gone
* Mon Sep  9 2024 Markéta Machová <mmachova@suse.com>
- Add patch numpy2.patch to fix build with the new numpy
* Thu Apr 22 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Tue May 12 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix python2 conditions to pull deps correctly
* Mon May 11 2020 andy great <andythe_great@pm.me>
- Bring back build for python 2.
- Fix dependencies for building with python 2.
* Sat May  9 2020 andy great <andythe_great@pm.me>
- Update to version 0.5.6
  * In 0.5.5 a for-loop was omitted which lead to every frame being
    the zeroth frame in the stack. For this reason, upgrading from
    0.5.5 is _strongly_ recommended.
- Clean up spec file.
* Tue Dec 10 2019 Todd R <toddrme2178@gmail.com>
- initial version
